@@ -8,13 +8,13 @@ Installation
 
     $ pip install algorithm
 
-We `test <https://travis-ci.org/gittip/algorithm.py>`_ against
+We `test <https://travis-ci.org/AspenWeb/algorithm.py>`_ against
 Python 2.6, 2.7, 3.2, and 3.3.
 
 :py:mod:`algorithm` is MIT-licensed.
 
 
-.. _GitHub: https://github.com/gittip/algorithm.py
+.. _GitHub: https://github.com/AspenWeb/algorithm.py
 .. _PyPI: https://pypi.python.org/pypi/algorithm
 
 
@@ -101,7 +101,7 @@ Just for kicks, let's remove the ``foo`` function while we're at it:
     [<function bar ...>, <function uh_oh ...>, <function bloo ...>, <function deal_with_it ...>]
 
 
-If you're making extension changes to an algorithm, you should feel free to
+If you're making extensive changes to an algorithm, you should feel free to
 directly manipulate the list of functions, rather than using the more
 cumbersome :py:meth:`~algorithm.Algorithm.insert_before`,
 :py:meth:`~algorithm.Algorithm.insert_after`, and
@@ -161,7 +161,7 @@ import types
 from dependency_injection import resolve_dependencies
 
 
-__version__ = '1.0.0'
+__version__ = '1.1.0'
 PYTHON_2 = sys.version_info < (3, 0, 0)
 
 
@@ -201,6 +201,9 @@ class Algorithm(object):
     functions = None        #: A list of functions comprising the algorithm.
     default_raise_immediately = False
 
+    START = -1
+    END = -2
+
 
     def __init__(self, *functions, **kw):
         self.default_raise_immediately = kw.pop('raise_immediately', False)
@@ -353,45 +356,93 @@ class Algorithm(object):
         return [f.__name__ for f in self.functions]
 
 
-    def insert_before(self, name, newfunc):
-        """Insert ``newfunc`` in the :py:attr:`functions` list before the function named
+    def insert_before(self, name, *newfuncs):
+        """Insert ``newfuncs`` in the :py:attr:`functions` list before the function named
         ``name``, or raise :py:exc:`FunctionNotFound`.
+
+        >>> def foo(): pass
+        >>> algo = Algorithm(foo)
+        >>> def bar(): pass
+        >>> algo.insert_before('foo', bar)
+        >>> algo.get_names()
+        ['bar', 'foo']
+        >>> def baz(): pass
+        >>> algo.insert_before('foo', baz)
+        >>> algo.get_names()
+        ['bar', 'baz', 'foo']
+        >>> def bal(): pass
+        >>> algo.insert_before(Algorithm.START, bal)
+        >>> algo.get_names()
+        ['bal', 'bar', 'baz', 'foo']
+        >>> def bah(): pass
+        >>> algo.insert_before(Algorithm.END, bah)
+        >>> algo.get_names()
+        ['bal', 'bar', 'baz', 'foo', 'bah']
+
+
         """
-        self.insert_relative_to(name, newfunc, relative_position=0)
+        if name == self.START:
+            i = 0
+        elif name == self.END:
+            i = len(self.functions)
+        else:
+            i = self.functions.index(self[name])
+        self.functions[i:i] = newfuncs
 
 
-    def insert_after(self, name, newfunc):
-        """Insert ``newfunc`` in the :py:attr:`functions` list after the function named
+    def insert_after(self, name, *newfuncs):
+        """Insert ``newfuncs`` in the :py:attr:`functions` list after the function named
         ``name``, or raise :py:exc:`FunctionNotFound`.
+
+        >>> def foo(): pass
+        >>> algo = Algorithm(foo)
+        >>> def bar(): pass
+        >>> algo.insert_after('foo', bar)
+        >>> algo.get_names()
+        ['foo', 'bar']
+        >>> def baz(): pass
+        >>> algo.insert_after('bar', baz)
+        >>> algo.get_names()
+        ['foo', 'bar', 'baz']
+        >>> def bal(): pass
+        >>> algo.insert_after(Algorithm.START, bal)
+        >>> algo.get_names()
+        ['bal', 'foo', 'bar', 'baz']
+        >>> def bah(): pass
+        >>> algo.insert_before(Algorithm.END, bah)
+        >>> algo.get_names()
+        ['bal', 'foo', 'bar', 'baz', 'bah']
+
         """
-        self.insert_relative_to(name, newfunc, relative_position=1)
+        if name == self.START:
+            i = 0
+        elif name == self.END:
+            i = len(self.functions)
+        else:
+            i = self.functions.index(self[name]) + 1
+        self.functions[i:i] = newfuncs
 
 
-    def insert_relative_to(self, name, newfunc, relative_position):
-        func = self[name]
-        index = self.functions.index(func) + relative_position
-        self.functions.insert(index, newfunc)
-
-
-    def remove(self, name):
-        """Remove the function named ``name`` from the :py:attr:`functions` list, or raise
+    def remove(self, *names):
+        """Remove the functions named ``name`` from the :py:attr:`functions` list, or raise
         :py:exc:`FunctionNotFound`.
         """
-        func = self[name]
-        self.functions.remove(func)
+        for name in names:
+            func = self[name]
+            self.functions.remove(func)
 
 
     @classmethod
     def from_dotted_name(cls, dotted_name, **kw):
-        """Construct a new instance from an algorithm definition module.
+        """Construct a new instance from functions defined in a Python module.
 
-        :param dotted_name: the dotted name of a Python module containing an
-            algorithm definition
+        :param dotted_name: the dotted name of a Python module that contains
+            functions that will be added to algorithm in the order of appearance.
 
         :param kw: keyword arguments are passed through to the default constructor
 
-        This is a convenience constructor that lets you take an algorithm
-        definition from a regular Python file. For example, create a file named
+        This is a convenience constructor to instantiate an algorithm based on
+        functions defined in a regular Python file. For example, create a file named
         ``blah_algorithm.py`` on your ``PYTHONPATH``::
 
             def foo():
@@ -414,6 +465,11 @@ class Algorithm(object):
 
         >>> blah.functions #doctest: +ELLIPSIS
         [<function foo ...>, <function bar ...>, <function bloo ...>]
+        
+        For this specific module, the code above is equivalent to:
+        
+        >>> from blah_algorithm import foo, bar, bloo
+        >>> Algorithm(foo, bar, bloo)
 
         """
         module = cls._load_module_from_dotted_name(dotted_name)
